<?php

namespace ReloadifyScoped\Doctrine\DBAL\Driver;

use ReloadifyScoped\Doctrine\DBAL\Connection;
use ReloadifyScoped\Doctrine\DBAL\Driver;
use ReloadifyScoped\Doctrine\DBAL\Driver\API\ExceptionConverter;
use ReloadifyScoped\Doctrine\DBAL\Driver\API\SQLite;
use ReloadifyScoped\Doctrine\DBAL\Platforms\AbstractPlatform;
use ReloadifyScoped\Doctrine\DBAL\Platforms\SqlitePlatform;
use ReloadifyScoped\Doctrine\DBAL\Schema\SqliteSchemaManager;
use ReloadifyScoped\Doctrine\Deprecations\Deprecation;
use function assert;
/**
 * Abstract base implementation of the {@see Doctrine\DBAL\Driver} interface for SQLite based drivers.
 */
abstract class AbstractSQLiteDriver implements Driver
{
    /**
     * {@inheritDoc}
     */
    public function getDatabasePlatform()
    {
        return new SqlitePlatform();
    }
    /**
     * {@inheritDoc}
     *
     * @deprecated Use {@link SqlitePlatform::createSchemaManager()} instead.
     */
    public function getSchemaManager(Connection $conn, AbstractPlatform $platform)
    {
        Deprecation::triggerIfCalledFromOutside('doctrine/dbal', 'https://github.com/doctrine/dbal/pull/5458', 'AbstractSQLiteDriver::getSchemaManager() is deprecated.' . ' Use SqlitePlatform::createSchemaManager() instead.');
        assert($platform instanceof SqlitePlatform);
        return new SqliteSchemaManager($conn, $platform);
    }
    public function getExceptionConverter() : ExceptionConverter
    {
        return new SQLite\ExceptionConverter();
    }
}
