<?php

/*
 * This file is part of the Symfony package.
 *
 * (c) Fabien Potencier <fabien@symfony.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace ReloadifyScoped\Symfony\Component\Translation\Test;

use ReloadifyScoped\PHPUnit\Framework\MockObject\MockObject;
use ReloadifyScoped\PHPUnit\Framework\TestCase;
use ReloadifyScoped\Psr\Log\LoggerInterface;
use ReloadifyScoped\Symfony\Component\HttpClient\MockHttpClient;
use ReloadifyScoped\Symfony\Component\Translation\Dumper\XliffFileDumper;
use ReloadifyScoped\Symfony\Component\Translation\Loader\LoaderInterface;
use ReloadifyScoped\Symfony\Component\Translation\Provider\ProviderInterface;
use ReloadifyScoped\Symfony\Component\Translation\TranslatorBagInterface;
use ReloadifyScoped\Symfony\Contracts\HttpClient\HttpClientInterface;
/**
 * A test case to ease testing a translation provider.
 *
 * @author Mathieu Santostefano <msantostefano@protonmail.com>
 */
abstract class ProviderTestCase extends TestCase
{
    protected HttpClientInterface $client;
    protected LoggerInterface|MockObject $logger;
    protected string $defaultLocale;
    protected LoaderInterface|MockObject $loader;
    protected XliffFileDumper|MockObject $xliffFileDumper;
    protected TranslatorBagInterface|MockObject $translatorBag;
    public static abstract function createProvider(HttpClientInterface $client, LoaderInterface $loader, LoggerInterface $logger, string $defaultLocale, string $endpoint) : ProviderInterface;
    /**
     * @return iterable<array{0: ProviderInterface, 1: string}>
     */
    public static abstract function toStringProvider() : iterable;
    /**
     * @dataProvider toStringProvider
     */
    public function testToString(ProviderInterface $provider, string $expected)
    {
        $this->assertSame($expected, (string) $provider);
    }
    protected function getClient() : MockHttpClient
    {
        return $this->client ??= new MockHttpClient();
    }
    protected function getLoader() : LoaderInterface
    {
        return $this->loader ??= $this->createMock(LoaderInterface::class);
    }
    protected function getLogger() : LoggerInterface
    {
        return $this->logger ??= $this->createMock(LoggerInterface::class);
    }
    protected function getDefaultLocale() : string
    {
        return $this->defaultLocale ??= 'en';
    }
    protected function getXliffFileDumper() : XliffFileDumper
    {
        return $this->xliffFileDumper ??= $this->createMock(XliffFileDumper::class);
    }
    protected function getTranslatorBag() : TranslatorBagInterface
    {
        return $this->translatorBag ??= $this->createMock(TranslatorBagInterface::class);
    }
}
